import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:path_stack/path_stack.dart';

import 'simple_tab_example_pages.dart';

/// 3 top-level routes, all mapped to an enum value.
///
/// Routes 1 and 2 retain state. Notice their buildCount's updating when you switch tabs.
/// The 3rd route is set to `maintainState: false`, so build count will always reset to 0

enum PageType { Home, Explore, Settings }

class SimpleTabExample extends StatefulWidget {
  @override
  _SimpleTabExampleState createState() => _SimpleTabExampleState();
}

class _SimpleTabExampleState extends State<SimpleTabExample> {
  PageType _currentPage = PageType.Home;
  @override
  Widget build(BuildContext context) {
    String currentPath = describeEnum(_currentPage);
    return PathStack(
      path: currentPath,
      transitionBuilder: (_, stack, anim) => FadeTransition(opacity: anim, child: stack),
      scaffoldBuilder: (_, stack) => TabScaffold(_currentPage, child: stack, onTabPressed: _handleTabPressed),
      routes: {
        ["${describeEnum(PageType.Home)}"]: HomePage().buildStackRoute(),
        ["${describeEnum(PageType.Settings)}"]: SettingsPage().buildStackRoute(),
        ["${describeEnum(PageType.Explore)}"]: ExplorePage().buildStackRoute(maintainState: false),
      },
    );
  }

  // Change page type and rebuild the parent view
  void _handleTabPressed(PageType value) => setState(() => _currentPage = value);
}
